Source-Changes-HG archive

[Date Prev][Date Next][Thread Prev][Thread Next][Date Index][Thread Index][Old Index]

[src/thorpej_scsipi]: src/sys/dev/scsipi Fix merge botch.



details:   https://anonhg.NetBSD.org/src/rev/40fede561cc3
branches:  thorpej_scsipi
changeset: 477298:40fede561cc3
user:      thorpej <thorpej%NetBSD.org@localhost>
date:      Wed Oct 20 22:42:04 1999 +0000

description:
Fix merge botch.

diffstat:

 sys/dev/scsipi/atapi_wdc.c |  14 +++++++-------
 1 files changed, 7 insertions(+), 7 deletions(-)

diffs (41 lines):

diff -r d81a1b2f58a9 -r 40fede561cc3 sys/dev/scsipi/atapi_wdc.c
--- a/sys/dev/scsipi/atapi_wdc.c        Wed Oct 20 22:31:06 1999 +0000
+++ b/sys/dev/scsipi/atapi_wdc.c        Wed Oct 20 22:42:04 1999 +0000
@@ -1,4 +1,4 @@
-/*     $NetBSD: atapi_wdc.c,v 1.27.2.3 1999/10/20 22:39:42 thorpej Exp $       */
+/*     $NetBSD: atapi_wdc.c,v 1.27.2.4 1999/10/20 22:42:04 thorpej Exp $       */
 
 /*
  * Copyright (c) 1998 Manuel Bouyer.
@@ -147,17 +147,18 @@
 }
 
 /*
  * Kill off all pending xfers for a scsipi_link.
  *
  * Must be called at splbio().
  */
 void
-atapi_kill_pending(sc_link)
-       struct scsipi_link *sc_link;
+atapi_kill_pending(periph)
+       struct scsipi_periph *periph;
 {
-       struct wdc_softc *wdc = (void *)sc_link->adapter_softc;
+       struct wdc_softc *wdc =
+           (void *)periph->periph_channel->chan_adapter->adapt_dev;
        struct channel_softc *chp =
-           wdc->channels[sc_link->scsipi_atapi.channel];
+           wdc->channels[periph->periph_channel->chan_channel];
 
        wdc_kill_pending(chp);
 }
@@ -172,7 +173,6 @@
        untimeout(wdctimeout, chp);
        /* remove this command from xfer queue */
        wdc_free_xfer(chp, xfer);
-       sc_xfer->xs_status |= XS_STS_DONE;
        sc_xfer->error = XS_DRIVER_STUFFUP;
        scsipi_done(sc_xfer);
 }
@@ -147,17 +147,18 @@
 
 /*
- * Kill off all pending xfers for a scsipi_link.
+ * Kill off all pending xfers for a periph.
  *
  * Must be called at splbio().



Home | Main Index | Thread Index | Old Index